@@ -58,7 +58,10 @@ class CreateForm(forms.SelfHandlingForm):
         share_networks = manila.share_network_list(request)
         share_types = manila.share_type_list(request)
         self.fields['share_type'].choices = (
-            [("", "")] + [(st.name, st.name) for st in share_types])
+            [("", "")] +
+            [(utils.transform_dashed_name(st.name), st.name)
+             for st in share_types]
+        )
 
         availability_zones = manila.availability_zone_list(request)
         self.fields['availability_zone'].choices = (
@@ -82,14 +85,18 @@ class CreateForm(forms.SelfHandlingForm):
                 sn_choices = (
                     [('', '')] +
                     [(sn.id, sn.name or sn.id) for sn in share_networks])
-                sn_field_name = self.sn_field_name_prefix + st.name
+                sn_field_name = (
+                    self.sn_field_name_prefix +
+                    utils.transform_dashed_name(st.name)
+                )
                 sn_field = forms.ChoiceField(
                     label=_("Share Network"), required=True,
                     choices=sn_choices,
                     widget=forms.Select(attrs={
                         'class': 'switched',
                         'data-switch-on': 'sharetype',
-                        'data-sharetype-%s' % st.name: _("Share Network"),
+                        'data-sharetype-%s' % utils.transform_dashed_name(
+                            st.name): _("Share Network"),
                     }))
                 self.fields[sn_field_name] = sn_field
 
@@ -128,12 +135,12 @@ class CreateForm(forms.SelfHandlingForm):
                 self.fields['size'].initial = snapshot.size
                 self.fields['snapshot'].choices = ((snapshot.id, snapshot),)
                 try:
-                    # Set the share type from the original share
+                    # Set the share type and az from the original share
                     orig_share = manila.share_get(request, snapshot.share_id)
-                    # NOTE(vponomaryov): we should use share type name, not ID,
-                    # because we use names in our choices above.
                     self.fields['share_type'].initial = (
                         orig_share.share_type_name)
+                    self.fields['availability_zone'].initial = (
+                        orig_share.availability_zone)
                 except Exception:
                     pass
                 self.fields['size'].help_text = _(
@@ -174,20 +181,19 @@ class CreateForm(forms.SelfHandlingForm):
         cleaned_data = super(CreateForm, self).clean()
         form_errors = list(self.errors)
 
-        # NOTE(vponomaryov): skip errors for share-network fields that are not
-        # related to chosen share type.
-        for error in form_errors:
-            st_name = error.split(self.sn_field_name_prefix)[-1]
-            chosen_st = cleaned_data.get('share_type')
-            if (error.startswith(self.sn_field_name_prefix) and
-                    st_name != chosen_st):
-                cleaned_data[error] = 'Not set'
-                self.errors.pop(error, None)
+        chosen_share_type = cleaned_data.get('share_type')
+        if chosen_share_type:
+            # NOTE(vponomaryov): skip errors for share-network fields that are
+            # not related to chosen share type.
+            for error in form_errors:
+                st_name = error.split(self.sn_field_name_prefix)[-1]
+                if (error.startswith(self.sn_field_name_prefix) and
+                        st_name != chosen_share_type):
+                    cleaned_data[error] = 'Not set'
+                    self.errors.pop(error, None)
 
-        share_type = cleaned_data.get('share_type')
-        if share_type:
             cleaned_data['share_network'] = cleaned_data.get(
-                self.sn_field_name_prefix + share_type)
+                self.sn_field_name_prefix + cleaned_data.get('share_type'))
 
         return cleaned_data
 
@@ -228,10 +234,10 @@ class CreateForm(forms.SelfHandlingForm):
                 proto=data['share_proto'],
                 share_network=share_network,
                 snapshot_id=snapshot_id,
-                share_type=data['share_type'],
+                share_type=utils.transform_dashed_name(data['share_type']),
                 is_public=is_public,
                 metadata=metadata,
-                availability_zone=data['availability_zone'],
+                availability_zone=data.get('availability_zone') or None,
                 share_group_id=data.get('sg') or None,
             )
             message = _('Creating share "%s"') % data['name']
@@ -328,15 +334,29 @@ class AddRule(forms.SelfHandlingForm):
         choices=(('rw', 'read-write'), ('ro', 'read-only'),))
     access_to = forms.CharField(
         label=_("Access To"), max_length="255", required=True)
+    metadata = forms.CharField(
+        label=_("Metadata"), required=False,
+        widget=forms.Textarea(attrs={'rows': 4}))
 
     def handle(self, request, data):
         share_id = self.initial['share_id']
+        metadata = {}
+        try:
+            set_dict, unset_list = utils.parse_str_meta(data['metadata'])
+            if unset_list:
+                msg = _("Expected only pairs of key=value.")
+                raise ValidationError(message=msg)
+            metadata = set_dict
+        except ValidationError as e:
+            self.api_error(e.messages[0])
+            return False
         try:
             manila.share_allow(
                 request, share_id,
                 access_to=data['access_to'],
                 access_type=data['access_type'],
-                access_level=data['access_level'])
+                access_level=data['access_level'],
+                metadata=metadata)
             message = _('Creating rule for "%s"') % data['access_to']
             messages.success(request, message)
             return True
@@ -347,6 +367,40 @@ class AddRule(forms.SelfHandlingForm):
                 request, _('Unable to add rule.'), redirect=redirect)
 
 
+class UpdateRuleMetadataForm(forms.SelfHandlingForm):
+    metadata = forms.CharField(widget=forms.Textarea,
+                               label=_("Metadata"), required=False)
+
+    def __init__(self, *args, **kwargs):
+        super(UpdateRuleMetadataForm, self).__init__(*args, **kwargs)
+        rule_metadata = utils.metadata_to_str(
+            self.initial["metadata"]
+        ).replace('<br/>', '\r\n')
+        self.initial["metadata"] = rule_metadata
+
+    def handle(self, request, data):
+        rule_id = self.initial['rule_id']
+        try:
+            rule = manila.share_rule_get(self.request, rule_id)
+            set_dict, unset_list = utils.parse_str_meta(data['metadata'])
+            if set_dict:
+                manila.share_rule_set_metadata(request, rule, set_dict)
+            if unset_list:
+                manila.share_rule_unset_metadata(request, rule, unset_list)
+            message = _('Updating share access rule metadata ')
+            messages.success(request, message)
+            return True
+        except ValidationError as e:
+            self.api_error(e.messages[0])
+            return False
+        except Exception:
+            redirect = reverse("horizon:project:shares:manage_rules",
+                               args=[self.initial['share_id']])
+            exceptions.handle(request,
+                              _('Unable to update rule metadata.'),
+                              redirect=redirect)
+
+
 class ResizeForm(forms.SelfHandlingForm):
     name = forms.CharField(
         max_length="255", label=_("Share Name"),
