@@ -36,6 +36,10 @@ urlpatterns = [
         r'^(?P<share_id>[^/]+)/rule_add/$',
         shares_views.AddRuleView.as_view(),
         name='rule_add'),
+    urls.url(
+        r'^rules/(?P<rule_id>[^/]+)/update_rule_metadata/$',
+        shares_views.UpdateRuleMetadataView.as_view(),
+        name='update_rule_metadata'),
     urls.url(
         r'^(?P<share_id>[^/]+)/$',
         shares_views.DetailView.as_view(),
